telemetry

package
v0.0.0-...-1d2b2b8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 14, 2025 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetTracer

func GetTracer() trace.Tracer

GetTracer returns the global tracer instance

func NewTelemetryProvider

func NewTelemetryProvider(ctx context.Context, serviceName string) (shutdown func(context.Context) error, err error)

NewTelemetryProvider creates and configures an OpenTelemetry TracerProvider, MeterProvider, and LoggerProvider. Pass the context and service name to initialize the telemetry system. It returns a shutdown function to clean up resources and an error if any step fails.

Types

This section is empty.

Jump to