Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTelemetryProvider ¶
func NewTelemetryProvider(ctx context.Context, serviceName string) (shutdown func(context.Context) error, err error)
NewTelemetryProvider creates and configures an OpenTelemetry TracerProvider, MeterProvider, and LoggerProvider. Pass the context and service name to initialize the telemetry system. It returns a shutdown function to clean up resources and an error if any step fails.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.